@@ -799,43 +799,60 @@ postag_func_kp = {  # doc,start, end, tag
 		{"nac": [d[e-1].lemma_ + f":{d[e-1].pos_}:AP|" +  d[s:e].text, d[e-1].lemma_ + f":{d[e-1].pos_}|AP"],  "tags": ' '.join([t.tag_ for t in d[s:e]])}}) ,
 	"vpn": lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
 		{"nac": [f"{d[s].lemma_}:VERB:vpn|{d[s].lemma_} {d[s+1:e].text}", f"{d[s].lemma_}:VERB|vpn", f"{d[s].lemma_}:VERB:vpn|{d[s].lemma_} {d[s+1].text} _NOUN",
-				f"{d[e-1].lemma_}:NOUN:vpn|{d[s].lemma_} {d[s+1:e].text}", f"{d[e-1].lemma_}:NOUN|vpn", f"{d[e-1].lemma_}:NOUN:vpn|_VERB {d[s+1:e].text}"]} }) , # _VERB with force, jump over the dog? 
+				f"{d[e-1].lemma_}:NOUN:vpn|{d[s].lemma_} {d[s+1:e].text}", f"{d[e-1].lemma_}:NOUN|vpn", f"{d[e-1].lemma_}:NOUN:vpn|_VERB {d[s+1:e].text}", 
+				f"{d[e-1].lemma_}/NOUN|vpn:{d[s].lemma_} {d[s+1:e].text}",  # force/NOUN|vpn:come into force
+				]} }) , # _VERB with force, jump over the dog? 
 	"bpn": lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
 		{"nac": [f"{d[s].lemma_}:VERB:vpn|{d[s].lemma_} {d[s+1:e].text}", f"{d[s].lemma_}:VERB|vpn", f"{d[s].lemma_}:VERB:vpn|{d[s].lemma_} {d[s+1].text} _NOUN",
-			f"{d[e-1].lemma_}:NOUN:vpn|{d[s].lemma_} {d[s+1:e].text}", f"{d[e-1].lemma_}:NOUN|vpn", f"{d[e-1].lemma_}:NOUN:vpn|_VERB {d[s+1:e].text}"] }}) , # be with force, be is a VERB
+			f"{d[e-1].lemma_}:NOUN:vpn|{d[s].lemma_} {d[s+1:e].text}", f"{d[e-1].lemma_}:NOUN|vpn", f"{d[e-1].lemma_}:NOUN:vpn|_VERB {d[s+1:e].text}",
+			f"{d[e-1].lemma_}/NOUN|vpn:{d[s].lemma_} {d[s+1:e].text}", ] }}) , # be with force, be is a VERB
 	"vnp": lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
 		{"nac": [f"{d[s].lemma_}:VERB:vnp|{d[s].lemma_} {d[s+1:e].text}", f"{d[s].lemma_}:VERB|vnp", f"{d[s].lemma_}:VERB:vnp|{d[s].lemma_} _NOUN {d[s+2].text}",
-				f"{d[s+1].lemma_}:NOUN:vnp|{d[s].lemma_} {d[s+1:e].text}", f"{d[s+1].lemma_}:NOUN|vnp", f"{d[s+1].lemma_}:NOUN:vnp|_VERB {d[s+1:e].text}"]}}) ,
+				f"{d[s+1].lemma_}:NOUN:vnp|{d[s].lemma_} {d[s+1:e].text}", f"{d[s+1].lemma_}:NOUN|vnp", f"{d[s+1].lemma_}:NOUN:vnp|_VERB {d[s+1:e].text}",
+				f"{d[s].lemma_}/VERB|vnp:{d[s].lemma_} {d[s+1:e].text}",]}}) ,
 	"vp":  lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
-		{"nac": [f"{d[s].lemma_}:VERB:vp|{d[s].lemma_} {d[s+1].text}", f"{d[s].lemma_}:VERB|vp", f"{d[s+1].lemma_}:{d[s+1].pos_}:vp|_VERB {d[s+1].text}"] }}) ,
+		{"nac": [f"{d[s].lemma_}:VERB:vp|{d[s].lemma_} {d[s+1].text}", f"{d[s].lemma_}:VERB|vp", f"{d[s+1].lemma_}:{d[s+1].pos_}:vp|_VERB {d[s+1].text}",
+				 f"{d[s].lemma_}/VERB|vp:{d[s].lemma_} {d[s+1].text}",	] }}) ,
 	"vpp": lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
-		{"nac": [f"{d[s].lemma_}:VERB:vpp|{d[s].lemma_} {d[s+1:e].text}", f"{d[s].lemma_}:VERB|vpp"] }}) ,
+		{"nac": [f"{d[s].lemma_}:VERB:vpp|{d[s].lemma_} {d[s+1:e].text}", f"{d[s].lemma_}:VERB|vpp"
+				 f"{d[s].lemma_}/VERB|vpp:{d[s].lemma_} {d[s+1:e].text}", ] }}) ,
 	"vpg": lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
-		{"nac": [f"{d[s].lemma_}:VERB:vpg|{d[s].lemma_} {d[s+1].text}", f"{d[s].lemma_}:VERB|vpg", f"{d[s].lemma_}:VERB:vpg|_{d[s].lemma_} {d[s+1].text} _VBG"] }}) ,
+		{"nac": [f"{d[s].lemma_}:VERB:vpg|{d[s].lemma_} {d[s+1].text}", f"{d[s].lemma_}:VERB|vpg", f"{d[s].lemma_}:VERB:vpg|_{d[s].lemma_} {d[s+1].text} _VBG", 
+			f"{d[s].lemma_}/VERB|vpg:{d[s].lemma_} {d[s+1].text} _VBG"] }}) ,
 	"pn":  lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
-		{"nac": [f"{d[s+1].lemma_}:NOUN:pn|{d[s:e].text.lower()}", f"{d[s+1].lemma_}:NOUN|pn"] }}) ,
+		{"nac": [f"{d[s+1].lemma_}:NOUN:pn|{d[s:e].text.lower()}", f"{d[s+1].lemma_}:NOUN|pn",
+			f"{d[s+1].lemma_}/NOUN|pn:{d[s:e].text.lower()}", ] }}) ,
 	"pnp": lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
-		{"nac": [f"{d[s+1].lemma_}:NOUN:pnp|{d[s:e].text.lower()}", f"{d[s+1].lemma_}:NOUN:pnp"] }}) ,
+		{"nac": [f"{d[s+1].lemma_}:NOUN:pnp|{d[s:e].text.lower()}", f"{d[s+1].lemma_}:NOUN:pnp",
+			f"{d[s+1].lemma_}/NOUN|pnp:{d[s:e].text.lower()}",] }}) ,
 	"bapv": lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
 		{"nac": [f"{d[s+1].lemma_}:ADJ:bapv|{d[s].lemma_} {d[s+1:e].text}", f"{d[s+1].lemma_}:ADJ|bapv", f"{d[s+1].lemma_}:ADJ:bapv|_{d[s].lemma_} {d[s+1:e-1].text} _VERB"]}}) ,  
 	"batv": lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
 		{"nac": [f"{d[s+1].lemma_}:ADJ:batv|{d[s].lemma_} {d[s+1:e].text}", f"{d[s+1].lemma_}:ADJ|batv", f"{d[s+1].lemma_}:ADJ:batv|_{d[s].lemma_} {d[s+1:e-1].text} _VERB"]}}) ,  
 	"bepv": lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
-		{"nac": [f"{d[s+1].lemma_}:VERB:bepv|{d[s].lemma_} {d[s+1:e].text}",f"{d[s+1].lemma_}:VERB|bepv", f"{d[s+1].lemma_}:VERB:bepv|_be {d[s+1:e-1].text} _VERB"]}}) , # _be forced to _VERB
+		{"nac": [f"{d[s+1].lemma_}:VERB:bepv|{d[s].lemma_} {d[s+1:e].text}",f"{d[s+1].lemma_}:VERB|bepv", f"{d[s+1].lemma_}:VERB:bepv|_be {d[s+1:e-1].text} _VERB",
+			f"{d[s+1].lemma_}/VERB|bepv:{d[s].lemma_} {d[s+1:e-1].text} _{d[e-1].tag_}",]}}) , # _be forced to _VERB
 	"betv": lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
-		{"nac": [f"{d[s+1].lemma_}:VERB:betv|{d[s].lemma_} {d[s+1:e].text}",f"{d[s+1].lemma_}:VERB|betv", f"{d[s+1].lemma_}:VERB:betv|_be {d[s+1:e-1].text} _VERB"]}}) , # _be forced to _VERB
+		{"nac": [f"{d[s+1].lemma_}:VERB:betv|{d[s].lemma_} {d[s+1:e].text}",f"{d[s+1].lemma_}:VERB|betv", f"{d[s+1].lemma_}:VERB:betv|_be {d[s+1:e-1].text} _VERB",
+		     f"{d[s+1].lemma_}/VERB|betv:{d[s].lemma_} {d[s+1:e-1].text} _{d[e-1].tag_}",]}}) , # _be forced to _VERB
 	"bap": lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
-		{"nac": [f"{d[s+1].lemma_}:ADJ:bap|{d[s].lemma_} {d[s+1:e].text}", f"{d[s+1].lemma_}:ADJ|bap"]}}) ,
+		{"nac": [f"{d[s+1].lemma_}:ADJ:bap|{d[s].lemma_} {d[s+1:e].text}", f"{d[s+1].lemma_}:ADJ|bap",
+				f"{d[s+1].lemma_}/ADJ|bap:{d[s].lemma_} {d[s+1:e].text}",]}}) ,
 	"bep": lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
-		{"nac": [f"{d[s+1].lemma_}:VERB:bep|{d[s].lemma_} {d[s+1:e].text}", f"{d[s+1].lemma_}:VERB|bep"]}}) ,
+		{"nac": [f"{d[s+1].lemma_}:VERB:bep|{d[s].lemma_} {d[s+1:e].text}", f"{d[s+1].lemma_}:VERB|bep",
+				f"{d[s+1].lemma_}/VERB|bep:{d[s].lemma_} {d[s+1:e].text}",]}}) ,
 	"vop": lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
-		{"nac": [f"{d[s].lemma_}:VERB:vop|{d[s].lemma_} oneself {d[e-1].text}", f"{d[s].lemma_}:VERB|vop",  f"{d[s].lemma_}:VERB:vop|_{d[s].lemma_} _oneself {d[e-1].text}"]}}) ,
+		{"nac": [f"{d[s].lemma_}:VERB:vop|{d[s].lemma_} oneself {d[e-1].text}", f"{d[s].lemma_}:VERB|vop",  f"{d[s].lemma_}:VERB:vop|_{d[s].lemma_} _oneself {d[e-1].text}",
+			f"{d[s].lemma_}/VERB|vop:{d[s].lemma_} oneself {d[e-1].text.lower()}",]}}) ,
 	"vtv": lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
-		{"nac": [f"{d[s].lemma_}:VERB:vtv|{d[s].lemma_} {d[s+1:e].text}", f"{d[s].lemma_}:VERB:vtv|_{d[s].lemma_} {d[s+1:e-1].text} _VERB", f"{d[s].lemma_}:VERB|vtv", f"{d[e-1].lemma_}:VERB|~vtv", f"{d[e-1].lemma_}:VERB:~vtv|{d[s].lemma_}"]}} ) ,
+		{"nac": [f"{d[s].lemma_}:VERB:vtv|{d[s].lemma_} {d[s+1:e].text}", f"{d[s].lemma_}:VERB:vtv|_{d[s].lemma_} {d[s+1:e-1].text} _VERB", f"{d[s].lemma_}:VERB|vtv", f"{d[e-1].lemma_}:VERB|~vtv", f"{d[e-1].lemma_}:VERB:~vtv|{d[s].lemma_}",
+			f"{d[s].lemma_}/VERB|vtv:{d[s].lemma_} to _{d[e-1].tag_}",]}} ) ,
 	"vg": lambda d,s,e,tag: d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
-		{"nac": [f"{d[s].lemma_}:VERB:vg|{d[s].lemma_} {d[e-1].text}", f"{d[s].lemma_}:VERB:vg|_{d[s].lemma_} _VBG", f"{d[s].lemma_}:VERB|vg", f"{d[e-1].lemma_}:VERB|~vg", f"{d[e-1].lemma_}:VERB:~vg|{d[s].lemma_}"]}}) , 
+		{"nac": [f"{d[s].lemma_}:VERB:vg|{d[s].lemma_} {d[e-1].text}", f"{d[s].lemma_}:VERB:vg|_{d[s].lemma_} _VBG", f"{d[s].lemma_}:VERB|vg", f"{d[e-1].lemma_}:VERB|~vg", f"{d[e-1].lemma_}:VERB:~vg|{d[s].lemma_}",
+				f"{d[s].lemma_}/VERB|vg:{d[s].lemma_} _{d[e-1].tag_}",]}}) , 
 	"vdpg": lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
-		{"nac": [f"{d[s].lemma_}:VERB:vdpg|{d[s].lemma_} {d[s+1:e].text}", f"{d[s].lemma_}:VERB|vdpg", f"_{d[s].lemma_} {d[s+1:e-1].text} _VBG"] }}),
+		{"nac": [f"{d[s].lemma_}:VERB:vdpg|{d[s].lemma_} {d[s+1:e].text}", f"{d[s].lemma_}:VERB|vdpg", f"_{d[s].lemma_} {d[s+1:e-1].text} _VBG",
+				f"{d[s].lemma_}/VERB|vdpg:{d[s].lemma_} {d[s+1:e-1].text} _{d[e-1].tag_}",] }}),
 	}
 
 def postag_match(doc, func=lambda doc,start,end,tag: doc.spans.update({f"postag[{start},{end}):{tag}": SpanGroup(doc, name=tag, spans=[ doc[start : end] ], attrs={}) } ) ): 
@@ -848,10 +865,10 @@ def postag_match(doc, func=lambda doc,start,end,tag: doc.spans.update({f"postag[
 		"AP":  [[{"POS": {"IN": ["ADV"]}, "OP": "+"}, {"POS": 'ADJ'}]],  
 		"vpn": [[{"POS":"VERB","TAG": {"NOT_IN": ["VBN"]}}, {"POS":"ADP"} , {"TAG":"NN", "IS_LOWER":True}]],  # come into force 
 		"bpn": [[{"LEMMA":"be"}, {"POS":"ADP"} , {"TAG":"NN"}]],  # be in force => vpn 
-		"vnp": [[{"POS":"VERB"}, {"TAG":"NN"}, {"POS":"ADP"} ]],  # make use of, lay emphasis on
+		"vnp": [[{"POS":"VERB","TAG": {"NOT_IN": ["VBN"]}}, {"TAG":"NN"}, {"POS":"ADP"} ]],  # make use of, lay emphasis on
 		"vp": [[{"POS":"VERB","TAG": {"NOT_IN": ["VBN"]}}, {"POS":"ADP"} ]],  # abide by | distinguish from
-		"vpp": [[{"POS":"VERB"}, {"POS":"ADP"}, {"POS":"ADP"} ]], # live up to
-		"vpg": [[{"POS":"VERB"}, {"POS":"ADP"}, {"TAG":"VBG","DEP":"pcomp"} ]], # insisted on going
+		"vpp": [[{"POS":"VERB","TAG": {"NOT_IN": ["VBN"]}}, {"POS":"ADP"}, {"POS":"ADP"} ]], # live up to
+		"vpg": [[{"POS":"VERB","TAG": {"NOT_IN": ["VBN"]}}, {"POS":"ADP"}, {"TAG":"VBG","DEP":"pcomp"} ]], # insisted on going
 		"pn": [[{"POS":"ADP", "DEP":"prep"} , {"TAG":"NN", "DEP":"pobj"}]],  # by force
 		"pnp": [[{"POS":"ADP", "DEP":"prep"} , {"TAG":"NN", "DEP":"pobj"}, {"POS":"ADP", "DEP":"prep"}]],  # on account of
 		"bapv": [[{"LEMMA":"be"} , {"TAG":{"IN": ["JJ"]}}, {"POS":"ADP"}, {"POS":"VERB"}]],  # 
@@ -860,9 +877,9 @@ def postag_match(doc, func=lambda doc,start,end,tag: doc.spans.update({f"postag[
 		"betv": [[{"LEMMA":"be"} , {"TAG":{"IN": ["VBN"]}}, {"LEMMA":"to"}, {"TAG":"VB"}]],  # be considered to be/go
 		"bap": [[{"LEMMA":"be"} , {"TAG":{"IN": ["JJ"]}}, {"POS":"ADP"}]], #be ignorant of
 		"bep": [[{"LEMMA":"be"} , {"TAG":{"IN": ["VBN"]}}, {"POS":"ADP"}]],  # be forced to
-		"vop": [[{"POS":"VERB"} , {"TEXT": {"REGEX": "[a-z]+self$"}}, {"POS":"ADP"}]], #throw oneself into
-		"vtv": [[{"POS":"VERB"}, {"LEMMA":"to"}, {"POS":"VERB", "DEP":"xcomp"} ]], 
-		"vg": [[{"POS":"VERB"},  {"TAG":"VBG", "DEP":"xcomp"} ]], 
+		"vop": [[{"POS":"VERB","TAG": {"NOT_IN": ["VBN"]}} , {"TEXT": {"REGEX": "[a-z]+self$"}}, {"POS":"ADP"}]], #throw oneself into
+		"vtv": [[{"POS":"VERB","TAG": {"NOT_IN": ["VBN"]}}, {"LEMMA":"to"}, {"POS":"VERB", "DEP":"xcomp"} ]], 
+		"vg": [[{"POS":"VERB","TAG": {"NOT_IN": ["VBN"]}},  {"TAG":"VBG", "DEP":"xcomp"} ]], 
 		"vdpg": [[{"POS":"VERB"},  {"POS":"ADV"} ,  {"POS":"ADP"} ,  {"TAG":"VBG"} ]],  # look forward to seeing
 		})
 	for name, start, end in postag_match.matcher(doc):
@@ -884,10 +901,10 @@ def skenp_match(doc, func=lambda doc,start,end,tag: doc.spans.update({f"skenp[{s
 	"vppn": [[{"POS":"VERB"}, {"POS":"ADP"}, {"POS":"ADP"}, {"ENT_TYPE":"NP"} ]],  # live up to _NP
 	"vdpn": [[{"POS":"VERB"}, {"POS":"ADV"}, {"POS":"ADP"}, {"ENT_TYPE":"NP"} ]],  # look back on _NP 
 	"vpnn": [[{"POS":"VERB"}, {"POS":"ADP"}, {"TAG":"NOUN"}, {"ENT_TYPE":"NP"} ]],  # I keep in mind the interconnectedness.
-	"vn": [[{"POS":"VERB"}, {"ENT_TYPE":"NP"} ]], 
-	"vnn": [[{"POS":"VERB"}, {"ENT_TYPE":"NP"}, {"ENT_TYPE":"NP"} ]], 
-	"vna": [[{"POS":"VERB"}, {"ENT_TYPE":"NP"}, {"POS":"ADJ"} ]], 
-	"vne": [[{"POS":"VERB"}, {"ENT_TYPE":"NP"}, {"TAG":"VBN"} ]], # leave it kept 
+	"vn": [[{"POS":"VERB"}, {"ENT_TYPE":"NP", "DEP":"dobj"} ]], 
+	"vnn": [[{"POS":"VERB"}, {"ENT_TYPE":"NP", "DEP":"dobj"}, {"ENT_TYPE":"NP", "DEP":"oprd"} ]], 
+	"vna": [[{"POS":"VERB"}, {"ENT_TYPE":"NP", "DEP":"dobj"}, {"POS":"ADJ", "DEP":"oprd"} ]], 
+	"vne": [[{"POS":"VERB"}, {"ENT_TYPE":"NP", "DEP":"dobj"}, {"TAG":"VBN"} ]], # leave it kept 
 	"vntb": [[{"POS":"VERB","TAG": {"NOT_IN": ["VBN"]}}, {"ENT_TYPE":"NP"}, {"LEMMA":"to"} , {"LEMMA":"be"}]], # consider _NP _NP | _NP _ADJ | _NP to be 
 	"vntv": [[{"POS":"VERB","TAG": {"NOT_IN": ["VBN"]}}, {"ENT_TYPE":"NP"}, {"LEMMA":"to"} , {"POS":"VERB"}]], # _force _NP to _VERB
 	"vntbn": [[{"POS":"VERB"}, {"ENT_TYPE":"NP"}, {"LEMMA":"to"} , {"LEMMA":"be"}, {"ENT_TYPE":"NP"}]], 
@@ -933,9 +950,13 @@ span_NP = lambda sp: " ".join([ "_NP" if t.ent_type_ == 'NP' else t.text.lower()
 def skenp_func_kp(doc, start, end, tag): # skenp_func_kp	= lambda doc, start, end, tag: doc.user_data.update({f"{tag}:{doc[start].lemma_} " + span_NP(doc[start+1:end]) : {"vlem":doc[start].lemma_, "start":start, "end":end, "nac": [f"{doc[start].lemma_}:VERB:{tag}|" +span_NP(doc[start:end] ), f"{doc[start].lemma_}:VERB|{tag}", f"*:VERB|{tag}"]} }) 
 	nac = [f"{doc[start].lemma_}:VERB:{tag}|" +span_NP(doc[start:end] ), f"{doc[start].lemma_}:VERB|{tag}", f"*:VERB|{tag}"]
 	if tag in ('vnpn'): # take _NP into account, added 2023.2.14
-		nac.extend([f"{doc[end-1].text.lower()}:NOUN:{tag}|" +doc[start].lemma_ + " " + span_NP(doc[start+1:end-1]) + " " + doc[end-1].text.lower(), f"{doc[end-1].text.lower()}:NOUN|{tag}", f"*:NOUN|{tag}"])
+		nac.extend([f"{doc[end-1].text.lower()}:NOUN:{tag}|" +doc[start].lemma_ + " " + span_NP(doc[start+1:end-1]) + " " + doc[end-1].text.lower(), f"{doc[end-1].text.lower()}:NOUN|{tag}", f"*:NOUN|{tag}", f"{doc[end-1].text.lower()}/NOUN|{tag}:" +doc[start].lemma_ + " " + span_NP(doc[start+1:end-1]) + " " + doc[end-1].text.lower()])
 	if tag in ("vnpe"): # take _NP for granted
-		nac.extend([f"{doc[end-1].lemma_}:VERB:{tag}|" +span_NP(doc[start:end]), f"{doc[end-1].lemma_}:VERB|{tag}", f"*:VERB|{tag}"])
+		nac.extend([f"{doc[end-1].lemma_}:VERB:{tag}|" +span_NP(doc[start:end]), f"{doc[end-1].lemma_}:VERB|{tag}", f"*:VERB|{tag}", f"{doc[end-1].lemma_}/VERB|vpne:" +span_NP(doc[start:end]),])
+	if tag in ("vn"): nac.extend([f"{doc[start].lemma_}/VERB|vn:{doc[start].lemma_} _NP"])
+	if tag == "vna": nac.extend([f"{doc[start].lemma_}/VERB|vna:{doc[start].lemma_} _NP _ADJ"])
+	if tag in ("vnn"): nac.extend([f"{doc[start].lemma_}/VERB|vnn:{doc[start].lemma_} _NP _NP"])
+	if tag in ("vne"): nac.extend([f"{doc[start].lemma_}/VERB|vne:{doc[start].lemma_} _NP _VBN"])
 	doc.user_data.update({f"{tag}:{doc[start].lemma_} " + span_NP(doc[start+1:end]) : {"vlem":doc[start].lemma_, "start":start, "end":end, "nac":nac} })
 
 trp3_func_kp = { #drink:VERB:dobj:NOUN:water:amod:ADJ safe
@@ -969,7 +990,7 @@ def kp_born(doc, base:bool=True):
 		[ doc.user_data.update({f"nbe:{t.lemma_} {t.head.text.lower()}[{t.head.i},{t.i}]": {"type":"trp",
 			'nac':[f"{t.lemma_}:{t.pos_}:nbe|{t.head.text.lower()}", f"{t.lemma_}:{t.pos_}|nbe", f"*:{t.pos_}|nbe",  # Smoking is banned. /VBG
 				f"{t.head.text.lower()}:{t.tag_}:nbe|{t.lemma_}", f"{t.head.text.lower()}:{t.tag_}|nbe", f"*:{t.tag_}|nbe",] } }) for t in doc if t.dep_ == 'nsubjpass' and t.head.tag_ == 'VBN' ] # the fate is sealed  / smiling is banned .
-		[ doc.user_data.update({f"vc:{t.head.lemma_}[{t.head.i},{t.i}]": {"type":"trp", 'nac':[f"{t.head.lemma_}:{t.head.pos_}|vc", f"*:{t.head.pos_}|vc"] } }) for t in doc if t.dep_ == 'ccomp' and t.head.pos_ == 'VERB' ]
+		[ doc.user_data.update({f"vc:{t.head.lemma_}[{t.head.i},{t.i}]": {"type":"trp", 'nac':[f"{t.head.lemma_}:{t.head.pos_}|vc", f"*:{t.head.pos_}|vc", f"{t.head.lemma_}/{t.head.pos_}|vc:{t.head.lemma_} _CL",] } }) for t in doc if t.dep_ == 'ccomp' and t.head.pos_ == 'VERB' ]
 		[ doc.user_data.update({f"ROOT-{t.tag_}:{t.lemma_}[{t.i}]": {"type":"trp","nac":[f"{t.lemma_}:{t.pos_}|ROOT"]} }) for t in doc if t.dep_ == 'ROOT' ]
 		[ doc.user_data.update({f"xcomp-{t.head.pos_}-{t.tag_}:{t.head.lemma_} {t.text}[{t.head.i},{t.i}]": {"type":"trp", 
 			"nac":[f"{t.head.lemma_}:{t.head.pos_}|xcomp:{t.tag_}", f"{t.head.lemma_}:{t.head.pos_}:xcomp:{t.tag_}|{t.text.lower()}",
@@ -999,7 +1020,7 @@ def kp_born(doc, base:bool=True):
 [setattr(builtins, k, v) for k, v in globals().items() if not k.startswith("_") and not '.' in k and not hasattr(builtins,k) ] #setattr(builtins, "spacy", spacy)
 if __name__	== '__main__': 
 	import fire, platform
-	[ print ( kp, item) for kp, item in kp_born(spacy.nlp("I take it into account.")).items()]  if platform.system() in ('Windows') else fire.Fire({"sqlsi":sqlsi, "test":test, "es_submit":es_submit, "fasttext":fasttext })
+	[ print ( kp, item) for kp, item in kp_born(spacy.nlp("I take it into account, and I enjoy swimming.")).items()]  if platform.system() in ('Windows') else fire.Fire({"sqlsi":sqlsi, "test":test, "es_submit":es_submit, "fasttext":fasttext })
 
 #print(sntbr("[\u8bd1\u6587]The 55-kilometre Hong Kong Zhuhai-Macau Bridge is an extraordinary engineering. It is the world's longest sea-crossing transportation system combining bridges and tunnels, which joins the three cities of Hong Kong Zhuhai and Macao, cutting the travelling time among them from 3 hours to 30 minutes. The reinforced concrete bridge with huge spans fully not only proves that China has the ability to complete the record-breaking mega-construction, but also will enhance the regional integration and boost the economic growth. It plays a crucial role in the overall plan to develop China’s Great Bay Area, which China intends to turn into one rivaling those of San Francisco, New York and Tokyo in terms of technological innovation and economic prosperity.", with_pid=True))
 #c:\users\zhang\appdata\local\programs\python\python38\lib\site-packages  
