@@ -21,7 +21,12 @@ def vecso(snt:str="I am too tired to move on.", topk:int=10, name:str='dic'):
 	p = getattr(vecso, name) 
 	labels, distances = p.knn_query(vecs, k=topk)
 	maps = [{ row[0]: row[1] for row in getattr(vecso, f"conn_{name}").execute(f"select rowid, snt from snt where rowid in ({','.join([str(s) for s in label.tolist()])})" )} for label in labels] 	#list(conn.execute(f"select rowid, snt from snt where rowid in (6561,3843)" ))
-	return [ [ {"sid":l, "snt": map.get(l,''), "distance":d } for l, d in zip(label.tolist(), distance.tolist()) ] for label,distance,map in zip(labels, distances, maps) ][0]
+	return [ [ {"sid":l, "snt": map.get(l,''), "distance":d, "name":name } for l, d in zip(label.tolist(), distance.tolist()) ] for label,distance,map in zip(labels, distances, maps) ][0]
+
+@app.get('/hnswlib/snts')
+def vecso_snts(snt:str="I am too tired to move on.", topk:int=10, name:str="dic"): 
+	''' return json data for majiang listview, i: ["dic","sci","twit", "nju"], 2023.2.8 '''
+	return vecso(snt, topk, name.strip())
 
 @app.get('/hnswlib', response_class=HTMLResponse)
 def vecso_html(snt:str="I am too tired to move on.", topk:int=10, name:str='dic'): 
